pub fn current_span_context() -> Option<SpanContext>Expand description
The ambient span context for the current task, if one has been set.
pub fn current_span_context() -> Option<SpanContext>The ambient span context for the current task, if one has been set.