pub struct TraceTrajectory {
pub spans: Vec<SpanRecord>,
}Expand description
A wrapper around a collection of spans to facilitate easy trajectory assertions.
Fields
spans: Vec<SpanRecord>Implementations
Sourceimpl TraceTrajectory
impl TraceTrajectory
Sourcepub fn contains_tool_call(&self, tool_name: &str) -> bool
pub fn contains_tool_call(&self, tool_name: &str) -> bool
Checks if a specific tool was called during the trace.
Sourcepub fn has_errors(&self) -> bool
pub fn has_errors(&self) -> bool
Checks if an error span was recorded.
Sourcepub fn total_cost(&self) -> f64
pub fn total_cost(&self) -> f64
Calculates the total cost estimate of all spans in the trajectory.
Sourcepub fn total_latency_ms(&self) -> u64
pub fn total_latency_ms(&self) -> u64
Returns the latency of the root workflow/agent span.
Sourcepub fn total_input_tokens(&self) -> u64
pub fn total_input_tokens(&self) -> u64
Returns the total number of input tokens consumed across all LLM calls.