Module hitl

Module hitl 

Enums

HitlResponse

Functions

get_pending_approvals
Returns a list of all currently pending span IDs.
register_approval
Registers a pending approval and returns a receiver to await the user’s response.
resolve_approval
Resolves a pending approval with the given response.