Enums
Functions
- get_
pending_ approvals - Returns a list of all currently pending span IDs.
- register_
approval - Registers a pending approval and returns a receiver to await the user’s response.
- resolve_
approval - Resolves a pending approval with the given response.